import React, { CircularProgress, Container, Fade, TextField } from "@material-ui/core";
import { Check } from "@material-ui/icons";
import { useEffect, useState } from "react";
import { useEffectAfterMount } from "../../../hooks/MountEffects";
import { useTypingTimer } from "../SearchBoxFilter/TypingTimer";

export function SearchBar({ search, loading = false, children }) {
  const [queryString, stillTyping] = useTypingTimer();
  const [showAnimation, setShowAnimation] = useState(false);
  const [checkMarkOn, setCheckMarkOn] = useState(false);

  useEffectAfterMount(() => { search(queryString); }, [search, queryString]);
  useEffectAfterMount(() => { !showAnimation && !loading && setShowAnimation(true) }, [showAnimation, loading, setShowAnimation])

  const solidTime = 1250;
  const fadeTime = 1000;
  useEffect(() => {
    if (!loading) {
      setCheckMarkOn(true);
      const timeout = setTimeout(() => { setCheckMarkOn(false) }, solidTime)
      return () => clearTimeout(timeout);
    }
  }, [loading])


  const Loading = (
    <Fade in>
      <CircularProgress color="primary" />
    </Fade>
  );

  const Finished = (
    <Fade
      in={checkMarkOn}
      timeout={fadeTime}
      enter={false}
    >
      <Check color="primary" />
    </Fade>
  );

  const LoadingAnimation = loading ? Loading : Finished;

  return (
    <Container>
      <TextField fullWidth variant="outlined" label="search" onKeyUp={stillTyping}
        InputProps={{
          endAdornment:
            showAnimation && LoadingAnimation
        }}
      />
      <div>&nbsp;</div>
      {children}
    </Container>
  );
}