import React from 'react';
import { useCurrentlyActiveIOCs } from '../../api/SwaggerApi';
import { useEffect } from 'react';
import { LinearProgress, useTheme } from '@material-ui/core';
import { circularPalette } from '../common/Helper';
import { BarChart, Bar, Tooltip, ResponsiveContainer, CartesianGrid, XAxis, YAxis, Cell, LabelList } from 'recharts';

export default function ActiveIOCChart({title}) {

    const [activeIocs, getActiveIocs] = useCurrentlyActiveIOCs();
    const theme = useTheme();
    const GRAPH_THRESHOLD = 0.2;

    useEffect(() => {
        getActiveIocs();
    }, [getActiveIocs]
    );

    const iocObjToArray = () => {
        if (activeIocs) {
            return Object.values(activeIocs);
        }

        return [];
    }

    

    const renderCustomizedLabel = (props) => {
        const { x, y, width, value, fill } = props;
        const radius = 15;

        return (
            <g>
                <circle cx={x + width / 2} cy={y - radius - 10} r={radius} fill={fill} />
                <text x={x + width / 2} y={y - radius - 10} fill="#fff" textAnchor="middle" dominantBaseline="middle" style={{ fontWeight: 'bold' }}>
                    {value}
                </text>
            </g>
        );
    };

    return (activeIocs ?
        <>
            <div style={{ textAlign: 'center' }}>
                <h3>{title}</h3>
            </div>
            <ResponsiveContainer
                width="100%"
                aspect={2}
            >
                <BarChart data={iocObjToArray()} margin={{bottom: 80}}>
                    <XAxis dataKey="network" interval={0} angle= "-20" textAnchor= "end" sclaeToFit="true" verticalAnchor= "start"/>
                    <YAxis domain={[0, dataMax => (Math.floor(dataMax * (1 + GRAPH_THRESHOLD)))]} />
                    <CartesianGrid stroke="#ccc" strokeDasharray="5 5" />
                    <Bar dataKey="iocCount" fill={circularPalette(theme.palette.graph, 0)} 
                     isAnimationActive={false} minPointSize={10} name="No. of IOCs running">
                        {
                            iocObjToArray().map((entry, index) => (
                                <Cell fill={circularPalette(theme.palette.graph, index)} key={entry}/>
                            ))
                        }
                        <LabelList dataKey="iocCount" content={renderCustomizedLabel} />
                    </Bar>
                    <Tooltip cursor={false} />
                </BarChart>
            </ResponsiveContainer>

        </>
        :
        <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>

    );
}