import React, { useEffect } from "react";
import { Paper, Box, Grid, useTheme, makeStyles } from "@material-ui/core";
import { useStatistics } from "../../api/SwaggerApi";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ActiveIOCChart from "../../components/statistics/ActiveIOCChart";
import DeploymentLineChart from "../../components/statistics/DeploymentLineChart";
import { useActiveIOCHistory, useDeployedIOCStatistics } from '../../api/SwaggerApi';
import { pick } from "../../components/common/Helper";
import { PrimeKeyValueTable } from "../../components/common/PrimeKeyValueTable/PrimeKeyValueTable";

const clone = (obj) => Object.assign({}, obj);

const renameKey = (object, key, newKey) => {

    const clonedObj = clone(object);
    const targetKey = clonedObj[key];

    delete clonedObj[key];
    clonedObj[newKey] = targetKey;

    return clonedObj;
};

const useStyles = makeStyles((theme) => ({
    paper: {
      padding: theme.spacing(4),
    },
  }));

export function StatisticsView() {

    const classes = useStyles();

    const title = "Statistics";
    useGlobalAppBar(title);

    const [statistics, getStatistics] = useStatistics();

    useEffect(() =>
        getStatistics()
        , [getStatistics]
    );

    let prometheusStats = null;
    let dbStats = null;

    //rename "response fields" into readable format
    if (statistics) {
        prometheusStats = pick(statistics ?? {}, ["numberOfActiveIocs", "numberOfActiveHosts"]);
        prometheusStats = renameKey(prometheusStats, "numberOfActiveIocs", "Number of IOCs detected on ESS networks");
        prometheusStats = renameKey(prometheusStats, "numberOfActiveHosts", "Number of IOC hosts detected on ESS networks");

        dbStats = pick(statistics ?? {}, ["numberOfCreatedIocs", "numberOfActiveDeployments", "numberOfDeployments"]);
        dbStats = renameKey(dbStats, "numberOfCreatedIocs", "Number of IOCs registered");
        dbStats = renameKey(dbStats, "numberOfActiveDeployments", "Number of IOCs currently deployed");
        dbStats = renameKey(dbStats, "numberOfDeployments", "Total number of deployment jobs executed");
    }

    const theme = useTheme();

    return (
        <RootContainer>
            <h2>Statistics</h2>
            {statistics &&
                <Grid container direction="column" spacing={theme.spacing(0.5)}>
                    <Grid item xs={12}>
                        <PrimeKeyValueTable obj={prometheusStats} labels={["Network monitoring"]} />
                    </Grid>
                    <Grid item xs={12}>
                        <PrimeKeyValueTable obj={dbStats} labels={["According to the deployment tool"]} />
                    </Grid>
                </Grid>
            }


            <Box m={2} />

            <Paper className={classes.paper}>
                <DeploymentLineChart title="Successful deployments over time by the deployment tool" chartLabel="Deployed IOCs in time" hook={useDeployedIOCStatistics} />
            </Paper>

            <Box m={2} />
            
            <Paper className={classes.paper}>
                <ActiveIOCChart title="Number of IOCs currently detected on each ESS control network"/>
            </Paper>

            <Box m={2} />

            <Paper className={classes.paper}>
                <DeploymentLineChart title="Number of IOCs detected on ESS networks over time" chartLabel="Active IOCs over time" hook={useActiveIOCHistory} />
            </Paper>
        </RootContainer>
    )
}
